@@ -1,7 +1,7 @@
 from __future__ import absolute_import
 
 from lazyops.types.common import *
-from lazyops.types.models import BaseModel, BaseSettings, Schema, Field, validator
+from lazyops.types.models import BaseModel, BaseSettings, Schema, Field, validator, UrlModel, BaseDBUrl, PostgresDB, RedisDB, NatsDB
 from lazyops.types.classprops import lazyproperty, classproperty, cached_classproperty
 
 try:
